import numpy as np
from scipy.integrate import solve_ivp
from AcetonePFRFn import AcetonePFR
import matplotlib.pyplot as plt
from CpFn import CpAavg,CpAiravg
from findTFn import findT,findTa

Rgas = 8.314  # kJ/kmol/K also m3*kPa/kmol/K
Tref = 298.15  # K

MWA = 58.08  # kg/kmol
MWAir = 28.96  

NoTubes = 1000
TotalVolume = 2  # m3

VolPerTube = TotalVolume/NoTubes
TubeID = 26.7e-3  # m3
TubeXC = np.pi*TubeID**2/4
TubeLength = VolPerTube/TubeXC

U = 400  # kJ/m2/hr/K
A = 4/TubeID  # m2/m3

ReactorMassFeed = 7850  # kg/hr
FAM = ReactorMassFeed/NoTubes
FAF = FAM/MWA

TF = 1035  # K
P = 162  # kPa
CAF = P/Rgas/TF  # kmol/m3

AirFeed = 11088*8  # kg/hr
FaM = AirFeed/NoTubes
Fa = FaM/MWAir
TaF = 1250  # K
Ta0 = 1117.7  # K - estimate

# initial conditions
HfA = -216.67*1000  # acetone heat of formation, kJ/kmol
H0 = FAF*(CpAavg(TF)*(TF-Tref)+HfA)
Ha0 = Fa*CpAiravg(Ta0)*(Ta0-Tref)

vspan = [0., VolPerTube]
veval = np.linspace(0., VolPerTube, 200)

y0 = [ FAF, H0, Ha0 ]

result = solve_ivp(AcetonePFR,vspan,y0,t_eval=veval, \
                   method='LSODA',args=(FAF,CAF,TF,Fa,Ta0,U,A))

vs = result.t 
n = len(vs)
FAout = result.y[0,:]
FKout = FAF - FAout
FMout = FAF - FAout

Tout = np.zeros(n)
Hout = result.y[1,:]
for i in range(n):
    Tout[i] = findT(Hout[i],TF,FAout[i],FKout[i],FMout[i])

Haout = result.y[2,:]
Taout = np.zeros(n)
for i in range(n):
    Taout[i] = findTa(Haout[i],Ta0,Fa)
    
Conv = (FAF-FAout)/FAF * 100

plt.figure()
plt.plot(vs,FAout,c='k',label='Acetone')
plt.plot(vs,FKout,c='g',label='Ketene')
plt.grid()
plt.ylim(0, 0.14)
plt.xlabel('Reactor Volume - m3')
plt.tick_params(axis='x',labelrotation=-90)
plt.ylabel('Molar Flow Rate - kmol/hr')
plt.title('Molar Flow Rates')
plt.legend()

plt.figure()
plt.plot(vs,Tout,c='b',label='Reaction')
plt.plot(vs,Taout,c='r',label='Air')
plt.grid()
plt.xlabel('Reactor Volume - m3')
plt.tick_params(axis='x',labelrotation=-90)
plt.ylabel('Temperature - K')
plt.title('Temperature Profiles')
plt.legend()

plt.figure()
plt.plot(vs,Conv,c='g')
plt.grid()
plt.ylim(0, 100)
plt.xlabel('Reactor Volume - m3')
plt.tick_params(axis='x',labelrotation=-90)
plt.ylabel('Conversion - %')
plt.title('Conversion Profile')

print('\nAir Entry Temperature = {0:7.1f} K'.format(Taout[n-1]))

