import numpy as np
from scipy.integrate import solve_ivp
from AcetonePFRFn import AcetonePFR
from CpFn import CpAavg,CpAiravg
from findTFn import findTa

def SolvAcetone(Ta0):
    Rgas = 8.314  # kJ/kmol/K also m3*kPa/kmol/K
    Tref = 298.15  # K

    MWA = 58.08  # kg/kmol
    MWAir = 28.96  

    NoTubes = 1000
    TotalVolume = 2  # m3

    VolPerTube = TotalVolume/NoTubes
    TubeID = 26.7e-3  # m3

    U = 400  # kJ/m2/hr/K
    A = 4/TubeID  # m2/m3

    ReactorMassFeed = 7850  # kg/hr
    FAM = ReactorMassFeed/NoTubes
    FAF = FAM/MWA

    TF = 1035  # K
    P = 162  # kPa
    CAF = P/Rgas/TF  # kmol/m3

    AirFeed = 11088*8  # kg/hr
    FaM = AirFeed/NoTubes
    Fa = FaM/MWAir
    TaF = 1250  # K

    # initial conditions
    HfA = -216.67*1000  # acetone heat of formation, kJ/kmol
    H0 = FAF*(CpAavg(TF)*(TF-Tref)+HfA)
    Ha0 = Fa*CpAiravg(Ta0)*(Ta0-Tref)

    vspan = [0., VolPerTube]
    veval = np.linspace(0., VolPerTube, 200)

    y0 = [ FAF, H0, Ha0 ]

    result = solve_ivp(AcetonePFR,vspan,y0,t_eval=veval, \
                   method='LSODA',args=(FAF,CAF,TF,Fa,Ta0,U,A))

    vs = result.t 
    n = len(vs)

    Haout = result.y[2,:]
    Taout = np.zeros(n)
    for i in range(n):
        Taout[i] = findTa(Haout[i],Ta0,Fa)
    
    return Taout[n-1]-TaF

